## Aura API
* Wrapper de la API de <a href="https://auralist.ml">AuraList</a>, el cual incluye seguimiento de votos y búsqueda de bots.
* Necesitas un API Token para usar este NPM, lo puedes conseguir <a href="https://auralist.ml/api">aquí</a>

## Ejemplos de uso
 * ### Empezar
 ```js
 const AuraList = require('aura-api');
 const auraClient = new AuraList.Client({
     apiToken: "" // Tu token aquí
     trackOnly: null
     /*
        trackOnly es para especificar que bots quieres
        tener seguimiento de. (¡Solo bots tuyos!)
        No especificar o poner 'null' para seguir a
        todos los bots que tengas

        En caso de querer trackear solo ciertos bots,
        haz esto:

        trackOnly: ['ID-BOT']

        Puedes agregar varias IDs.
     */
 });
 auraClient.on('ready', () => {
     console.log("Conectado a AuraList")
 });

 auraClient.connect();
 ```
 * ### Seguimiento de votos
 ```js
 auraClient.on('vote', (upvote) => { 
     console.log(upvote);
     /*
        Debería loguear un objeto como:
        {
            user: {
                id: string,
                username: string,
                tag: string,

                //Hash del avatar
                avatar: string,
                
                // Esto es una función para obtener la URL del avatar
                // Las opciones son las mismas que usando Discord.JS
                displayAvatarURL(options: AvatarOptions): string
            },
            bot: {
                id: string,
                clientId: string,
                username: string,
                tag: string,

                votes: {
                    before: number, // Votos antes
                    after: number // Votos actuales
                },
                //Hash del avatar
                avatar: string,
                
                // Esto es una función para obtener la URL del avatar
                // Las opciones son las mismas que usando Discord.JS
                displayAvatarURL(options: AvatarOptions): string
            }
        }
     */
 });
 ```
 * ### Buscador
 ```js
 const searcher = new AuraList.Searcher(aToken); 
 // Mismo token que el de votos

 searcher.getBot('ID-BOT') // Promise<BotInfo>
 .then(bot => { // BotInfo
    console.log(bot);
    /*
        Deberia loguear un objeto como:
        {
            clientId: string,
            id: string,
            username: string,
            tag: string,
            ownerId: string,

            avatarURL: string,

            shortDescription: string,
            largeDescription: string,

            certified: boolean,
            verified: boolean,
            vanity: string | null,
            prefix: string,
            tags: string[],
            upvotes: number,

            supportURL: string | null,
            inviteURL: string | null,
            websiteURL: string | null,

            addedAt: Date
        }
    */
 })
 .catch(console.error)
 ```
 * ### Debug
 ```js
 auraClient.on('debug', console.log);
 ```

¿Tienes problemas o no entiendes como hacer algo?
Puedes hacer tus preguntas en nuestro <a href="https://discord.gg/ss93pdZzrF">servidor de discord</a>