declare module 'aura-api' {
    export interface ConnectionOptions {
        apiToken: string;
        trackOnly?: string[]
    }
    export interface AvatarOptions {
        dynamic?: boolean;
        format?: "jpg" | "png" | "gif" | "webp";
        size?: number;
    }
    export interface PartialUpvoter {
        id: string;
        username: string;
        tag: string;

        avatar: string;
        displayAvatarURL(options: AvatarOptions): string;
    }
    export interface PartialUpvotedBot {
        id: string;
        username: string;
        tag: string;

        votes: {
            before: number;
            after: number;
        };

        avatar: string;
        displayAvatarURL(options: AvatarOptions): string;
    }
    export interface UpvoteInfo {
        user: PartialUpvoter;
        bot: PartialUpvotedBot;
    }
    export interface ClientEvents {
        vote: [upvoteInfo: UpvoteInfo];
        debug: [message: string];
        ready: [];
    }
    export interface BotInfo {
        clientId: string;
        id: string;
        username: string;
        tag: string;
        ownerId: string;

        avatarURL: string;

        shortDescription: string;
        largeDescription: string;

        certified: boolean;
        verified: boolean;
        vanity: string | null;
        prefix: string
        tags: string[];
        upvotes: number;

        supportURL: string | null;
        inviteURL: string | null;
        websiteURL: string | null;

        addedAt: Date;
    }

    export class Client {
        public apiToken: string;
        public ws?: WebSocket;
        public trackOnly?: string[];

        public constructor(options: ConnectionOptions);

        public on<K extends keyof ClientEvents>(
            event: K,
            listener: (...args: ClientEvents[K]) => any
        ): this;

        public connect(): Promise<string>;
        public destroy(): Promise<void>;
    }

    export class Searcher {
        public apiToken: string;
        public constructor(apiToken: string);

        public getBot(id: string): Promise<BotInfo>;
    }
    export = {
        Client, Searcher
    };
}